'use strict';
var fs = require('fs');
var util = require('util');
var path = require('path');
var spawn = require('child_process').spawn;
var yeoman = require('yeoman-generator');
var yosay = require('yosay');
var chalk = require('chalk');
var engine = require('ejs').render;
var htmlWiring = require('html-wiring');
var mkdirp = require('mkdirp');

var AppGenerator = module.exports = function Appgenerator(args, options, config) {
  console.log('Hey there, flyweight.');

  yeoman.Base.apply(this, arguments);
  this.options = options;
  this.pkg = JSON.parse(htmlWiring.readFileAsString(path.join(__dirname, '../package.json')));
};

util.inherits(AppGenerator, yeoman.Base);

AppGenerator.prototype.packageJSON = function () {
  this.template('_package.json', 'package.json');
};

AppGenerator.prototype.gitIgnore = function () {
  this.copy('gitignore', '.gitignore');
};

AppGenerator.prototype.readme = function () {
  this.copy('README.md', 'README.md');
};

AppGenerator.prototype.js = function () {
  this.copy('scripts/index.js', 'app/scripts/index.js');
};

AppGenerator.prototype.mainStylesheet = function () {
  this.copy('styles/app.sass', 'app/styles/app.sass');
};

AppGenerator.prototype.writeIndex = function () {
  this.indexFile = htmlWiring.readFileAsString(path.join(this.sourceRoot(), 'index.html'));
  this.indexFile = engine(this.indexFile, this);
};

AppGenerator.prototype.copyIcons = function () {
  this.fs.copy(
    this.templatePath('favicon.ico'),
    this.destinationPath('app/favicon.ico')
  );
}

AppGenerator.prototype.install = function() {
  this.npmInstall([], {'loglevel': 'error'});
};

AppGenerator.prototype.app = function () {
  mkdirp('app');
  mkdirp('app/scripts');
  mkdirp('app/styles');
  mkdirp('app/images');
  mkdirp('app/fonts');

  this.write('app/index.html', this.indexFile);
};
